@@ -1,13 +1,38 @@
 """
 Utility code for parsing git history.
 """
+import os
 import re
 import subprocess
+import sys
 from typing import List, Optional, Tuple
 
 leading_4_spaces = re.compile("^    ")
 
 
+def _get_git_command() -> str:
+    if sys.platform.startswith("win"):
+        proc = subprocess.Popen(
+            ["where", "git"], stdout=subprocess.PIPE, stderr=subprocess.PIPE
+        )
+        proc.wait()
+        git_paths, err = proc.communicate()
+        if err:
+            raise FileNotFoundError(err.decode(sys.stdout.encoding))
+        git_paths = git_paths.decode(sys.stdout.encoding).split("\n")
+        try:
+            for exepath in git_paths:
+                exepath = exepath.strip()
+                if os.access(exepath, os.X_OK):
+                    return exepath
+        except OSError:
+            pass
+
+        return "git.cmd"
+    else:
+        return "git"
+
+
 def get_commits(
     since_date: Optional[str] = None, until_date: Optional[str] = None
 ) -> List:
@@ -34,13 +59,21 @@ def get_commits(
         Commit information is a dict containing "title", "date", "files" and more.
     """
     if since_date and until_date:
-        command = ["git", "log", "--stat", "--since", since_date, "--until", until_date]
+        command = [
+            _get_git_command(),
+            "log",
+            "--stat",
+            "--since",
+            since_date,
+            "--until",
+            until_date,
+        ]
     else:
-        command = ["git", "log", "--stat"]
+        command = [_get_git_command(), "log", "--stat"]
 
     try:
         lines = (
-            subprocess.check_output(command, stderr=subprocess.STDOUT, shell=True)
+            subprocess.check_output(command, stderr=subprocess.STDOUT)
             .decode("utf-8")
             .split("\n")
         )
@@ -93,9 +126,8 @@ def get_commits(
 def _get_tag_date(tag_name: str) -> str:
     return (
         subprocess.check_output(
-            ["git", "log", "-1", "--format=%ai", tag_name],
+            [_get_git_command(), "log", "-1", "--format=%ai", tag_name],
             stderr=subprocess.STDOUT,
-            shell=True,
         )
         .decode("utf-8")
         .split(" ")[0]
@@ -114,13 +146,13 @@ def list_tags() -> List[Tuple[str, str]]:
     try:
         tags = (
             subprocess.check_output(
-                ["git", "tag", "-n"], stderr=subprocess.STDOUT, shell=True
+                [_get_git_command(), "tag", "-n"], stderr=subprocess.STDOUT
             )
             .decode("utf-8")
             .split("\n")
         )
         tags.reverse()
-    except subprocess.CalledProcessError:
+    except (subprocess.CalledProcessError, FileNotFoundError):
         return []
 
     tags = [t.split(" ")[0] for t in tags]
@@ -130,7 +162,7 @@ def list_tags() -> List[Tuple[str, str]]:
 
 def has_git() -> bool:
     try:
-        subprocess.check_output(["git", "log"], stderr=subprocess.STDOUT, shell=True)
+        subprocess.check_output([_get_git_command(), "log"], stderr=subprocess.STDOUT)
     except (subprocess.CalledProcessError, FileNotFoundError):
         return False
     else:
